PhenoAI is a machine learning interface for applications in High Energy Physics Phenomenology. It allows the user to use trained machine learning algorithms from the PhenoAI algorithm library (see link below) via a consistent interface. Trained algorithms can be stored in a folder with PhenoAI structure using the maker module of the package and shared, making it possible to communicate full-dimensional results so that one does not have to flee to models with lower dimensionality or to project out informative dimensions of the full problem.

# Algorithm library

The current version of the package allows the user to use algorithms trained by scikit-learn and keras. These algorithms have to be created by the user, or have to be loaded from an external source like the algorithm library: [http://hef.ru.nl/~bstienen/phenoai](http://hef.ru.nl/~bstienen/phenoai) (work in progress).

# Documentation

Documentation, a quick start guide and a range of examples can be found on the official PhenoAI website: [http://hef.ru.nl/~bstienen/phenoai](http://hef.ru.nl/~bstienen/phenoai).

# Citation

[coming soon]

# To Do

- Add support for ROOT trained algorithms
